@@ -361,7 +361,7 @@ class Builder(Update):
             prefix=self.clVars.Get('cl_builder_path'))
 
         if repname not in ("gentoo", "portage"):
-            reposconf.remove(repname, rpath_orig)
+            reposconf.remove(repname)
             removeDir(rpath)
         return True
 
